==> vue-icon-3.23.0.tgz: package/lib/fullscreen-right.js <==
import { svg } from "@opentiny/vue-common";
import { createElementBlock, openBlock, createElementVNode } from "vue";
var _hoisted_1 = {
  width: "16",
  height: "16",
  viewBox: "0 0 16 16",
  fill: "none",
  xmlns: "http://www.w3.org/2000/svg"
};
var _hoisted_2 = /* @__PURE__ */ createElementVNode(
  "defs",
  null,
  [/* @__PURE__ */ createElementVNode("clipPath", {
    id: "fullscreen-right_svg__a"
  }, [/* @__PURE__ */ createElementVNode("path", {
    fill: "#fff",
    "fill-opacity": "0",
    d: "M0 0h16v16H0z"
  })])],
  -1
  /* HOISTED */
);
var _hoisted_3 = /* @__PURE__ */ createElementVNode(
  "g",
  {
    "clip-path": "url(#fullscreen-right_svg__a)"
  },
  [/* @__PURE__ */ createElementVNode("path", {
    d: "M9 3.5c-.28 0-.5.22-.5.5 0 .27.22.5.5.5h1.81L8.31 7c-.18.16-.21.44-.06.65.21.18.57.25.76.06l2.49-2.49V7c0 .24.16.44.41.49.27 0 .59-.23.59-.5V4.4c0-.5-.41-.9-.91-.9H9ZM7.68 8.28a.501.501 0 0 0-.7 0L4.5 10.77V9c0-.25-.17-.45-.42-.5-.27 0-.58.23-.58.5v2.6c0 .5.4.9.9.9H7c.27 0 .5-.22.5-.5 0-.27-.23-.5-.5-.5H5.18L7.68 9c.16-.19.16-.52 0-.72ZM4 2.5h8c.83 0 1.5.66 1.5 1.5v8c0 .83-.67 1.5-1.5 1.5H4c-.84 0-1.5-.67-1.5-1.5V4c0-.84.66-1.5 1.5-1.5Zm0-1C2.61 1.5 1.5 2.61 1.5 4v8c0 1.38 1.11 2.5 2.5 2.5h8a2.5 2.5 0 0 0 2.5-2.5V4c0-1.39-1.12-2.5-2.5-2.5H4Z",
    fill: "#191919"
  })],
  -1
  /* HOISTED */
);
var _hoisted_4 = [_hoisted_2, _hoisted_3];
function render(_ctx, _cache) {
  return openBlock(), createElementBlock("svg", _hoisted_1, [].concat(_hoisted_4));
}
var FullscreenRight = {
  render
};
var index = function index2() {
  return svg({
    name: "IconFullscreenRight",
    component: FullscreenRight
  })();
};
export {
  index as default
};

==> vue-icon-3.24.0.tgz: package/lib/fullscreen-right.js <==
import { svg } from "@opentiny/vue-common";
import { createElementBlock, openBlock, createElementVNode } from "vue";
var _hoisted_1 = {
  width: "16",
  height: "16",
  viewBox: "0 0 16 16",
  fill: "none",
  xmlns: "http://www.w3.org/2000/svg"
};
var _hoisted_2 = /* @__PURE__ */ createElementVNode(
  "defs",
  null,
  [/* @__PURE__ */ createElementVNode("clipPath", {
    id: "fullscreen-right_svg__a"
  }, [/* @__PURE__ */ createElementVNode("path", {
    fill: "#fff",
    "fill-opacity": "0",
    d: "M0 0h16v16H0z"
  })])],
  -1
  /* HOISTED */
);
var _hoisted_3 = /* @__PURE__ */ createElementVNode(
  "g",
  {
    "clip-path": "url(#fullscreen-right_svg__a)"
  },
  [/* @__PURE__ */ createElementVNode("path", {
    d: "M9 3.5c-.28 0-.5.22-.5.5 0 .27.22.5.5.5h1.81L8.31 7c-.18.16-.21.44-.06.65.21.18.57.25.76.06l2.49-2.49V7c0 .24.16.44.41.49.27 0 .59-.23.59-.5V4.4c0-.5-.41-.9-.91-.9H9ZM7.68 8.28a.501.501 0 0 0-.7 0L4.5 10.77V9c0-.25-.17-.45-.42-.5-.27 0-.58.23-.58.5v2.6c0 .5.4.9.9.9H7c.27 0 .5-.22.5-.5 0-.27-.23-.5-.5-.5H5.18L7.68 9c.16-.19.16-.52 0-.72ZM4 2.5h8c.83 0 1.5.66 1.5 1.5v8c0 .83-.67 1.5-1.5 1.5H4c-.84 0-1.5-.67-1.5-1.5V4c0-.84.66-1.5 1.5-1.5Zm0-1C2.61 1.5 1.5 2.61 1.5 4v8c0 1.38 1.11 2.5 2.5 2.5h8a2.5 2.5 0 0 0 2.5-2.5V4c0-1.39-1.12-2.5-2.5-2.5H4Z"
  })],
  -1
  /* HOISTED */
);
var _hoisted_4 = [_hoisted_2, _hoisted_3];
function render(_ctx, _cache) {
  return openBlock(), createElementBlock("svg", _hoisted_1, [].concat(_hoisted_4));
}
var FullscreenRight = {
  render
};
var index = function index2() {
  return svg({
    name: "IconFullscreenRight",
    component: FullscreenRight
  })();
};
export {
  index as default
};
